@@ -1,9 +1,10 @@
+#include <fstream>
 #include <TMB.hpp>
 #include <vector>
 #include <iostream>
 #include <numeric>
 #include <math.h>
-#include "init.h"
+// #include "init.h"
 #include "hawkes.h"
 #include "lgcp.h"
 #include "marked_lgcp.h"
@@ -51,3 +52,9 @@ Type objective_function<Type>::operator() ()
 }
 
   
+// RegisteringDynamic Symbols
+
+void R_init_stelfi(DllInfo* info) {
+  R_registerRoutines(info, NULL, NULL, NULL, NULL);
+  R_useDynamicSymbols(info, TRUE);
+}
